import { createRouter, createWebHistory } from 'vue-router'
import HomeView from '../views/HomeView.vue'
import store from '../store';
  
const routes = [
  {
    path: '/',
    name: 'home',
    component: HomeView
  },
  {
    path: '/:pathMatch(.*)*',
    component: () => import('../components/NotFound.vue')
  },
  {
    path: '/about',
    name: 'about',
    // route level code-splitting
    // this generates a separate chunk (about.[hash].js) for this route
    // which is lazy-loaded when the route is visited.
    component: () => import('../views/AboutView.vue')
  },
  {
    path: '/faqs',
    name: 'FAQs',
    component: () => import('../views/FaqsView.vue')
  },
  {
    path: '/contact',
    name: 'Contact Us',
    component: () => import('../views/ContactView.vue')
  },
  {
    path: '/login',
    name: 'login',
    component: () => import('../views/auth/LoginView.vue'),
    meta: {
      guest: true
    }
  },
  {
    path: '/recover-password',
    name: 'Recover Password',
    component: () => import('../views/auth/ResetPasswordView.vue'),
    meta: {
      guest: true
    }
  },
  {
    path: '/signup',
    name: 'Signup',
    component: () => import('../views/auth/SignupView.vue'),
    meta: {
      guest: true
    }
  },
  {
    path: '/policies/privacy-policy',
    name: 'privacy-policy',
    component: () => import('../views/policies/PrivacyPolicy.vue')
  },
  {
    path: '/policies/terms-of-service',
    name: 'terms',
    component: () => import('../views/policies/TermsofService.vue')
  },
  {
    path: '/collection/:id',
    name: 'collection',
    component: () => import('../views/collection/ListView.vue')
  },
  {
    path: '/policies/refund-policy',
    name: 'refund',
    component: () => import('../views/policies/RefundPolicy.vue')
  },
  {
    path: '/policies/shipping-policy',
    name: 'shipping',
    component: () => import('../views/policies/ShippingPolicy.vue')
  },
  {
    path: '/checkouts/information',
    name: 'checkouts',
    component: () => import('../components/Checkout/Checkout.vue'),
    props: true
  },
  {
    path: '/product/:id',
    name: 'product',
    component: () => import('../components/Product.vue')
  },
  {
    path: '/cart',
    name: 'cart',
    component: () => import('../components/Slices/Cart.vue')
  },
  {
    path: '/account',
    name: 'account',
    component: () => import('../views/pages/Account.vue'),
    meta: {
      auth: true
    }
  },
  {
    path: '/account/addresses',
    name: 'address',
    component: () => import('../views/pages/Address.vue'),
    meta: {
      auth: true
    }
  },
  {
    path: '/account/profile',
    name: 'profile',
    component: () => import('../views/pages/Profile.vue'),
    meta: {
      auth: true
    }
  },
  {
    path: '/search',
    name: 'search',
    component: () => import('../views/pages/Search.vue')
  },
  {
    path: '/checkouts/shipping',
    name: 'delivery_method',
    component: () => import('../components/Checkout/DeliveryMethod.vue'),
  },
  {
    path: '/checkouts/payment',
    name: 'payment',
    component: () => import('../components/Checkout/Payment.vue'),
  },
  {
    path: '/collections',
    name: 'collections',
    component: () => import('../views/collection/Collection.vue'),
  },
]

const router = createRouter({
  history: createWebHistory(),
  scrollBehavior() {
    // always scroll to top
    return { top: 0 }
  },
  routes
})

router.beforeEach((to, from, next) => {
  if (to.matched.some(record => record.meta.auth)) {
      if (!store.getters.GET_AUTH_STATUS) {
          next({
              name: 'login'
          })
      } else {
          next()
      }
   } else if (to.matched.some(record => record.meta.guest)) {
      if (store.getters.GET_AUTH_STATUS) {
          next({
              name: 'account'
          })
      } else {
          next()
      }
  } else{
      next()
  } 
})

export default router
